==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/plugin/lang/mr/lang.php <==
<?php
/**
 * Marathi language file
 *
 * @author ghatothkach@hotmail.com
 * @author Padmanabh Kulkarni <kulkarnipadmanabh@gmail.com>
 * @author Padmanabh Kulkarni<kulkarnipadmanabh@gmail.com>
 * @author shantanoo@gmail.com
 */
$lang['menu']                  = 'प्लगिनची व्यवस्था लावा';
$lang['download']              = 'नवीन प्लगिन डाउनलोड करून इन्स्टॉल करा';
$lang['manage']                = 'इन्स्टॉल केलेले प्लगिन';
$lang['btn_info']              = 'माहिती';
$lang['btn_update']            = 'अद्ययावत';
$lang['btn_delete']            = 'डिलीट';
$lang['btn_settings']          = 'सेटिंग';
$lang['btn_download']          = 'डाउनलोड';
$lang['btn_enable']            = 'सुरक्षित';
$lang['url']                   = 'URL';
$lang['installed']             = 'इन्स्टॉलची वेळ :';
$lang['lastupdate']            = 'शेवटच्या बदलाची वेळ :';
$lang['source']                = 'स्त्रोत :';
$lang['unknown']               = 'अगम्य';
$lang['updating']              = 'अद्ययावत करतोय ...';
$lang['updated']               = 'प्लगिन %s यशास्विरित्य अद्ययावत केला.';
$lang['updates']               = 'खालील प्लगिन यशस्वीरीत्या अद्ययावत झाले';
$lang['update_none']           = 'काही बदल मिळाले नाहीत.';
$lang['deleting']              = 'डिलीट करतोय ...';
$lang['deleted']               = '%s प्लगिन डिलीट केला.';
$lang['downloading']           = 'डाउनलोड करतोय ...';
$lang['downloaded']            = '%s प्लगिन यशस्वीरीत्या इन्स्टॉल झाला.';
$lang['downloads']             = 'खालील प्लगिन यशस्वीरीत्या इन्स्टॉल झाले : ';
$lang['download_none']         = 'एकही प्लगिन मिळाला नाही, किंवा डाउनलोड आणि इन्स्टॉल मधे काही अज्ञात अडचण आली असावी.';
$lang['plugin']                = 'प्लगिन : ';
$lang['components']            = 'भाग : ';
$lang['noinfo']                = 'या प्लगिनने काही माहिती दिली नाही. बहुधा हा अवैध असावा.';
$lang['name']                  = 'नाव :';
$lang['date']                  = 'दिनांक :';
$lang['type']                  = 'टाइप : ';
$lang['desc']                  = 'वर्णन : ';
$lang['author']                = 'लेखक : ';
$lang['www']                   = 'वेब : ';
$lang['error']                 = 'अज्ञात अडचण आली.';
$lang['error_download']        = 'डाउनलोड न झालेली प्लगिन फाइल  : %s';
$lang['error_badurl']          = 'बहुधा चुकीचे URL - URL  वरून फाइलचे नाव ठरवता आले नाही.';
$lang['error_dircreate']       = 'डाउनलोड साठवण्यासाठी तात्पुरता फोल्डर तयार करू शकलो नाही';
$lang['error_decompress']      = 'प्लगिन व्यवस्थापक डाउनलोड केलेली फाइल विस्तारित करू शकला नाही. हे कदाचित डाउनलोड नीट न झाल्यामुळे असावं; असे असल्यास तुमची परत डाउनलोड करण्याचा प्रयत्न करू शकता; किंवा प्लगिन संक्षिप्त करण्यास वापरलेली पद्धत अनाकलनीय आहे; तसे असल्यास तुम्हाला स्वतः प्लगिन डाउनलोड व इन्स्टॉल करावा लागेल.';
$lang['error_copy']            = '<em>%s</em> प्लगिनसाठी फाइल इन्स्टॉल करताना फाइल कॉपी करू शकलो नाही : डिस्क भरली असेल किंवा फाइल वरील परवानग्या बरोबर नसतील. यामुळे प्लगिन अर्धवट इन्स्टॉल जाला असण्याची व त्यामुळे तुमची विकी ख़राब होण्याची शक्यता आहे.';
$lang['error_delete']          = '<em>%s</em> प्लगिन डिलीट करताना काही चूक झाली आहे. फाइल किंवा डिरेक्टरी वरील परवानग्या बरोबर नसणे हे याचं मुख्य कारण असू शकतं.';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/plugin/lang/mr/lang.php <==
<?php
/**
 * Marathi language file
 *
 * @author ghatothkach@hotmail.com
 * @author Padmanabh Kulkarni <kulkarnipadmanabh@gmail.com>
 * @author Padmanabh Kulkarni<kulkarnipadmanabh@gmail.com>
 * @author shantanoo@gmail.com
 */
$lang['menu']                  = 'प्लगिनची व्यवस्था लावा';
$lang['download']              = 'नवीन प्लगिन डाउनलोड करून इन्स्टॉल करा';
$lang['manage']                = 'इन्स्टॉल केलेले प्लगिन';
$lang['btn_info']              = 'माहिती';
$lang['btn_update']            = 'अद्ययावत';
$lang['btn_delete']            = 'डिलीट';
$lang['btn_settings']          = 'सेटिंग';
$lang['btn_download']          = 'डाउनलोड';
$lang['btn_enable']            = 'सुरक्षित';
$lang['url']                   = 'URL';
$lang['installed']             = 'इन्स्टॉलची वेळ :';
$lang['lastupdate']            = 'शेवटच्या बदलाची वेळ :';
$lang['source']                = 'स्त्रोत :';
$lang['unknown']               = 'अगम्य';
$lang['updating']              = 'अद्ययावत करतोय ...';
$lang['updated']               = 'प्लगिन %s यशास्विरित्य अद्ययावत केला.';
$lang['updates']               = 'खालील प्लगिन यशस्वीरीत्या अद्ययावत झाले';
$lang['update_none']           = 'काही बदल मिळाले नाहीत.';
$lang['deleting']              = 'डिलीट करतोय ...';
$lang['deleted']               = '%s प्लगिन डिलीट केला.';
$lang['downloading']           = 'डाउनलोड करतोय ...';
$lang['downloaded']            = '%s प्लगिन यशस्वीरीत्या इन्स्टॉल झाला.';
$lang['downloads']             = 'खालील प्लगिन यशस्वीरीत्या इन्स्टॉल झाले : ';
$lang['download_none']         = 'एकही प्लगिन मिळाला नाही, किंवा डाउनलोड आणि इन्स्टॉल मधे काही अज्ञात अडचण आली असावी.';
$lang['plugin']                = 'प्लगिन : ';
$lang['components']            = 'भाग : ';
$lang['noinfo']                = 'या प्लगिनने काही माहिती दिली नाही. बहुधा हा अवैध असावा.';
$lang['name']                  = 'नाव :';
$lang['date']                  = 'दिनांक :';
$lang['type']                  = 'टाइप : ';
$lang['desc']                  = 'वर्णन : ';
$lang['author']                = 'लेखक : ';
$lang['www']                   = 'वेब : ';
$lang['error']                 = 'अज्ञात अडचण आली.';
$lang['error_download']        = 'डाउनलोड न झालेली प्लगिन फाइल  : %s';
$lang['error_badurl']          = 'बहुधा चुकीचे URL - URL  वरून फाइलचे नाव ठरवता आले नाही.';
$lang['error_dircreate']       = 'डाउनलोड साठवण्यासाठी तात्पुरता फोल्डर तयार करू शकलो नाही';
$lang['error_decompress']      = 'प्लगिन व्यवस्थापक डाउनलोड केलेली फाइल विस्तारित करू शकला नाही. हे कदाचित डाउनलोड नीट न झाल्यामुळे असावं; असे असल्यास तुमची परत डाउनलोड करण्याचा प्रयत्न करू शकता; किंवा प्लगिन संक्षिप्त करण्यास वापरलेली पद्धत अनाकलनीय आहे; तसे असल्यास तुम्हाला स्वतः प्लगिन डाउनलोड व इन्स्टॉल करावा लागेल.';
$lang['error_copy']            = '<em>%s</em> प्लगिनसाठी फाइल इन्स्टॉल करताना फाइल कॉपी करू शकलो नाही : डिस्क भरली असेल किंवा फाइल वरील परवानग्या बरोबर नसतील. यामुळे प्लगिन अर्धवट इन्स्टॉल जाला असण्याची व त्यामुळे तुमची विकी ख़राब होण्याची शक्यता आहे.';
$lang['error_delete']          = '<em>%s</em> प्लगिन डिलीट करताना काही चूक झाली आहे. फाइल किंवा डिरेक्टरी वरील परवानग्या बरोबर नसणे हे याचं मुख्य कारण असू शकतं.';
$lang['enabled']               = '%s प्लगइन चालू केला.';
$lang['notenabled']            = '%s प्लगइन चालू करू शकलो नाही, फाइलच्या परवानग्या तपासा.';
$lang['disabled']              = '%s प्लगइन बंद केला.';
$lang['notdisabled']           = '%s प्लगइन बंद करू शकलो नाही, फाइलच्या परवानग्या तपासा.';
